# PyEsoify
A simple python script to esotericify your python code.

**Contrary to popular belief, using an obfuscator or a tool like this does not prevent your code from theft or reverse engineering. It only makes it harder to read. If someone really cared enough about your code to steal it (which they most likely don't!), an obfuscator will not stop them.**
So, this project is just for fun and educational purposes. It shows you how you can push python to its limits.

## Features
- Support to esotericify most in-built python functions.
- Support to esotericify variable creation and assignment.

## Installation
You can install the package using pip:
```bash
pip install -U pyesoify
```

## Usage
```bash
python -m pyesoify <input_file> --output <output_file>
```
Specifying `--output` is optional, if not specified, the output will be printed to the console.

